==> gstreamer-0.7.3.tar.bz2: gstreamer-0.7.3/gst/gstmarshal.h <==

#ifndef __gst_marshal_MARSHAL_H__
#define __gst_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (gstmarshal.list:1) */
#define gst_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:BOOLEAN (gstmarshal.list:2) */
#define gst_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:INT (gstmarshal.list:3) */
#define gst_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:STRING (gstmarshal.list:4) */
#define gst_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:POINTER (gstmarshal.list:5) */
#define gst_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:POINTER,OBJECT (gstmarshal.list:6) */
extern void gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT (gstmarshal.list:7) */
#define gst_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,PARAM (gstmarshal.list:8) */
extern void gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,POINTER (gstmarshal.list:9) */
extern void gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,STRING (gstmarshal.list:10) */
extern void gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:INT,INT (gstmarshal.list:11) */
extern void gst_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:INT64 (gstmarshal.list:12) */
extern void gst_marshal_VOID__INT64 (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:UINT,BOXED (gstmarshal.list:13) */
extern void gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* BOOLEAN:VOID (gstmarshal.list:14) */
extern void gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* BOOLEAN:POINTER (gstmarshal.list:15) */
extern void gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

G_END_DECLS

#endif /* __gst_marshal_MARSHAL_H__ */

==> gstreamer-0.7.4.tar.bz2: gstreamer-0.7.4/gst/gstmarshal.h <==

#ifndef __gst_marshal_MARSHAL_H__
#define __gst_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:VOID (gstmarshal.list:1) */
#define gst_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:BOOLEAN (gstmarshal.list:2) */
#define gst_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN

/* VOID:INT (gstmarshal.list:3) */
#define gst_marshal_VOID__INT	g_cclosure_marshal_VOID__INT

/* VOID:STRING (gstmarshal.list:4) */
#define gst_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:POINTER (gstmarshal.list:5) */
#define gst_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:POINTER,OBJECT (gstmarshal.list:6) */
extern void gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT (gstmarshal.list:7) */
#define gst_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT

/* VOID:OBJECT,PARAM (gstmarshal.list:8) */
extern void gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
                                            const GValue *param_values,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);

/* VOID:OBJECT,POINTER (gstmarshal.list:9) */
extern void gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:OBJECT,POINTER,STRING (gstmarshal.list:10) */
extern void gst_marshal_VOID__OBJECT_POINTER_STRING (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

/* VOID:OBJECT,STRING (gstmarshal.list:11) */
extern void gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
                                             const GValue *param_values,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);

/* VOID:INT,INT (gstmarshal.list:12) */
extern void gst_marshal_VOID__INT_INT (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* VOID:INT64 (gstmarshal.list:13) */
extern void gst_marshal_VOID__INT64 (GClosure     *closure,
                                     GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint,
                                     gpointer      marshal_data);

/* VOID:UINT,BOXED (gstmarshal.list:14) */
extern void gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* VOID:UINT,POINTER (gstmarshal.list:15) */
#define gst_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER

/* BOOLEAN:VOID (gstmarshal.list:16) */
extern void gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
                                       const GValue *param_values,
                                       gpointer      invocation_hint,
                                       gpointer      marshal_data);

/* BOOLEAN:POINTER (gstmarshal.list:17) */
extern void gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

/* POINTER:POINTER (gstmarshal.list:18) */
extern void gst_marshal_POINTER__POINTER (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
                                          const GValue *param_values,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);

G_END_DECLS

#endif /* __gst_marshal_MARSHAL_H__ */
